@@ -1,4 +1,6 @@
 import os.path
+import sys
+import warnings
 from statistics import mode
 
 import matplotlib.pyplot as plt
@@ -7,6 +9,8 @@ import mlflow.tensorflow
 import numpy as np
 import pandas as pd
 import tensorflow as tf
+from datasets import load_dataset
+from huggingface_hub import from_pretrained_keras
 from matplotlib import cm
 from mpl_toolkits import mplot3d
 from numpy.random import seed
@@ -17,8 +21,6 @@ from sklearn.model_selection import train_test_split
 from sklearn.neighbors import NearestNeighbors
 from tensorflow.keras import layers, losses
 from tensorflow.keras.models import Model
-from datasets import load_dataset
-from huggingface_hub import from_pretrained_keras
 
 import bbobbenchmarks as bbob
 from models import VAE, Autoencoder
@@ -32,14 +34,14 @@ class doe_model:
         self,
         dim,
         m,
-        n=100000,
+        n=250000,
         latent_dim=32,
         seed_nr=0,
         kl_weight=0.001,
         custom_sample=None,
         use_mlflow=False,
         mlflow_name="Doc2Vec",
-        model_type="VAE"
+        model_type="VAE",
     ):
         """Doe2Vec model to transform Design of Experiments to feature vectors.
 
@@ -103,7 +105,11 @@ class doe_model:
         self.autoencoder.compile(optimizer="adam")
         self.functions = dataset["function"]
         self.Y = []
-        array_x = self.sample #this seemingly unused variable is required by the eval() later on
+        array_x = (
+            self.sample
+        )  # this seemingly unused variable is required by the eval() later on
+        if not sys.warnoptions:
+            warnings.simplefilter("ignore")
         for fun in self.functions:
             try:
                 array_y = eval(fun)
@@ -115,6 +121,7 @@ class doe_model:
                 self.Y.append(array_y)
             except:
                 continue
+        warnings.simplefilter("default")
         self.setData(self.Y)
         print("Loaded huggingface model and data")
         self.summary()
@@ -141,8 +148,6 @@ class doe_model:
             return True
         return False
 
-        
-
     def loadData(self, dir="data"):
         """Load a stored functions file and retrieve all the landscapes.
 
@@ -152,14 +157,14 @@ class doe_model:
         Returns:
             bool: True if loaded, else False.
         """
-        if os.path.exists(
-            f"{dir}/functions_d{self.dim}-n{self.n}.npy"
-        ):
-            self.functions = np.load(
-                f"{dir}/functions_d{self.dim}-n{self.n}.npy"
-            )
+        if os.path.exists(f"{dir}/functions_d{self.dim}-n{self.n}.npy"):
+            self.functions = np.load(f"{dir}/functions_d{self.dim}-n{self.n}.npy")
             self.Y = []
-            array_x = self.sample #this seemingly unused variable is required by the eval() later on
+            array_x = (
+                self.sample
+            )  # this seemingly unused variable is required by the eval() later on
+            if not sys.warnoptions:
+                warnings.simplefilter("ignore")
             for fun in self.functions:
                 try:
                     array_y = eval(fun)
@@ -171,6 +176,7 @@ class doe_model:
                     self.Y.append(array_y)
                 except:
                     continue
+            warnings.simplefilter("default")
             self.setData(self.Y)
             print("Loaded data")
             return True
@@ -194,6 +200,8 @@ class doe_model:
         self.Y = []
         self.functions = []
         tries = 0
+        if not sys.warnoptions:
+            warnings.simplefilter("ignore")
         while len(self.Y) < self.n:
             tries += 1
             # create an artificial function
@@ -222,11 +230,12 @@ class doe_model:
                 self.Y.append(array_y)
             except:
                 continue
+        warnings.simplefilter("default")
         self.Y = np.array(self.Y)
         self.functions = np.array(self.functions)
         self.train_data = tf.cast(self.Y[:-50], tf.float32)
         self.test_data = tf.cast(self.Y[-50:], tf.float32)
-        
+
         return self.Y
 
     def setData(self, Y):
@@ -250,13 +259,14 @@ class doe_model:
             self.autoencoder = Autoencoder(self.latent_dim, self.Y.shape[1])
             self.autoencoder.compile(optimizer="adam", loss=losses.MeanSquaredError())
 
-    def fit(self, epochs=100):
+    def fit(self, epochs=100, **kwargs):
         """Fit the autoencoder model.
 
         Args:
             epochs (int, optional): Number of epochs to train. Defaults to 100.
+            **kwargs (dict, optional): optional arguments for the fit procedure.
         """
-        if (self.autoencoder is None):
+        if self.autoencoder is None:
             raise AttributeError("Autoencoder model is not compiled yet")
         if self.use_mlflow:
             mlflow.tensorflow.autolog(every_n_iter=1)
@@ -267,6 +277,7 @@ class doe_model:
                 batch_size=128,
                 shuffle=True,
                 validation_data=(self.test_data, self.test_data),
+                **kwargs,
             )
         else:
             self.autoencoder.fit(
@@ -276,6 +287,7 @@ class doe_model:
                 batch_size=128,
                 shuffle=True,
                 validation_data=(self.test_data, self.test_data),
+                **kwargs,
             )
         self.fitNN()
         if self.use_mlflow:
@@ -332,9 +344,7 @@ class doe_model:
         Args:
             data_dir (str, optional): Directory to store the random functions. Defaults to "data".
         """
-        np.save(
-            f"{data_dir}/functions_d{self.dim}-n{self.n}.npy", self.functions
-        )   
+        np.save(f"{data_dir}/functions_d{self.dim}-n{self.n}.npy", self.functions)
 
     def encode(self, X):
         """Encode a Design of Experiments.
@@ -369,19 +379,7 @@ class doe_model:
                 )
                 encoded = self.encode([array_x])
                 encodings.append(encoded[0])
-                class_label = 0
-                if f in [1, 2, 3, 4, 5]:
-                    class_label = 1  # "separable"
-                elif f in [6, 7, 8, 9]:
-                    class_label = 2  # "low cond."
-                elif f in [10, 11, 12, 13, 14]:
-                    class_label = 3  # "high cond."
-                elif f in [15, 16, 17, 18, 19]:
-                    class_label = 4  # "multi modal gl."
-                elif f in [20, 21, 22, 23, 24]:
-                    class_label = 5  # "multi modal"
-
-                fuction_groups.append(class_label)
+                fuction_groups.append(f)
 
         X = np.array(encodings)
         y = np.array(fuction_groups).flatten()
@@ -403,7 +401,7 @@ class doe_model:
             mlflow.log_artifact("latent_space.png", "img")
         else:
             plt.savefig(
-                f"../mds/plot_{self.dim}-{self.m}-{self.latent_dim}-{self.seed}-{self.model_type}.png"
+                f"latent_space_{self.dim}-{self.m}-{self.latent_dim}-{self.seed}-{self.model_type}.png"
             )
 
     def visualizeTestData(self, n=5):
